<div class="ad-tip-block">
<p class="information">
If you found this useful, please  
<a href="https://www.paypal.com/xclick/business=rudd-o@rudd-o.com&amp;return=<?php bloginfo("url"); ?>"
title="Leave a tip &mdash; you choose how much!">leave a donation for the author</a>.
</p>
</div>
