<?php get_header(); ?>

	<div id="content">

	<?php if (have_posts()) : ?>
		
		<?php while (have_posts()) : the_post(); ?>
				
			<div class="post" id="post-<?php the_ID(); ?>">
				<h1 class="storytitle"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link to <?php the_title(); ?>"><?php the_title(); ?></a></h1>
				<div class="postmetadata">by <?php the_author() ?> — published on <?php the_time('F jS, Y') ?> <?php edit_post_link('Edit this entry','',''); ?></div>
				
				<div class="entry">
					<?php the_content('Read the rest of this entry &raquo;'); ?>
				</div>
		
				<?php include(TEMPLATEPATH."/adintermix.php"); ?>

				<div class="postmetadata">
				<div class="comments-slug">
				<?php comments_popup_link('No Comments &#187;', '1 Comment &#187;', '% Comments &#187;'); ?>
				</div>
				<div class="categories-slug">
				categories: <?php the_category(', ') ?>
				</div>
				</div>


			</div>

	
		<?php endwhile; ?>

		<div class="navigation"><div class="previous"><?php next_posts_link('&laquo; Older entries') ?></div><div class="next"><?php previous_posts_link('Newer entries &raquo;') ?></div></div>

	<?php else : ?>

		<h1 class="pagetitle">Oops... not found!</h2>
		<p class="center">Sorry, but you are looking for something that isn't here.  Please use the following search form if you remember a few words of the text you're looking for.</p>
		<?php include (TEMPLATEPATH . "/searchform.php"); ?>

	<?php endif; ?>

	</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>
