<?php
/*
Template Name: Links
*/
?>

<?php get_header(); ?>

<div id="content">

<h1 class="pagetitle">Links</h1>
<ul>
<?php get_links_list(); ?>
</ul>

</div>	

<?php get_sidebar(); ?>

<?php get_footer(); ?>
