<div class="ad-header">

<script type="text/javascript"><!--
google_ad_client = "pub-0872790598670514";
google_ad_width = 234;
google_ad_height = 60;
google_ad_format = "234x60_as";
google_ad_type = "text_image";
google_ad_channel ="3206765316";
google_color_border = "0000B8";
google_color_bg = "F1F1FB";
google_color_link = "0000CC";
google_color_url = "0000B8";
google_color_text = "111145";
//--></script>
<script type="text/javascript"
  src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
</script>

</div>
