<div class="searchform-container">
<form method="get" class="searchform" action="<?php echo $_SERVER['PHP_SELF']; ?>">
<input type="text" value="<?php echo wp_specialchars($s, 1); ?>" name="s" />
<input type="submit" name="searchsubmit" value="Search" />
</form>
</div>
