<?php if (isset($_GET["raw"])) {
	ob_start();
	echo "Content-Type: ".bloginfo('html_type')."; charset=".bloginfo('charset');
	$header = ob_get_contents();
	ob_end_clean();
	header($header);
?><head profile="http://gmpg.org/xfn/11">
<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />
</head>
<body>
<?php
		if (have_posts()) {
			while (have_posts()) {
				the_post();
				the_content('<p class="serif">Read the rest of this entry &raquo;</p>');
			}
		}
?>
</body>
<?php
	die();
}
?><?php get_header(); ?>

	<div id="content">

  <?php if (have_posts()) : while (have_posts()) : the_post(); ?>
	
		<div class="post" id="post-<?php the_ID(); ?>">
			<h1 class="storytitle"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link: <?php the_title(); ?>"><?php the_title(); ?></a></h1>
	
			<div class="postmetadata">by <?php the_author() ?> — published on <?php the_time('F jS, Y') ?> <?php edit_post_link('Edit this entry.','',''); ?></div>

                        <?php include(TEMPLATEPATH . "/adaftertitle.php"); ?>

			<div class="entry">
				<?php the_content('<p class="serif">Read the rest of this entry &raquo;</p>'); ?>
	
				<?php link_pages('<p><strong>Pages:</strong> ', '</p>', 'number'); ?>
	
		                <?php include(TEMPLATEPATH . "/adaftercontent.php"); ?>
	
                                <?php include(TEMPLATEPATH . "/adtipblock.php"); ?>
				
				<p class="postmetadata alt">
						This entry was posted
						on <?php the_time('l, F jS, Y') ?> at <?php the_time() ?>
						and is filed under <?php the_category(', ') ?>.
						You can follow any responses to this entry through the <?php comments_rss_link('RSS 2.0'); ?> feed. 
						
						<?php if (('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Both Comments and Pings are open ?>
							You can <a href="#respond">leave a response</a>, or <a href="<?php trackback_url(true); ?>" rel="trackback">trackback</a> from your own site.
						
						<?php } elseif (!('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Only Pings are Open ?>
							Responses are currently closed, but you can <a href="<?php trackback_url(true); ?> " rel="trackback">trackback</a> from your own site.
						
						<?php } elseif (('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Comments are open, Pings are not ?>
							You can skip to the end and leave a response. Pinging is currently not allowed.
			
						<?php } elseif (!('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Neither Comments, nor Pings are open ?>
							Both comments and pings are currently closed.
						
						<?php } ?>
						
				<?php if (function_exists("wp_sociable")) { ?>You can also share and bookmark this article on the following services: <span id="sociable-links"><?php wp_sociable(); ?></span><?php } ?>.

				</p>

				<?php if (function_exists('bccl_license_text_hyperlink')) { ?><p id="license-slug"><?php bccl_license_text_hyperlink(); ?><br/>Except where expressly acknowledged, this work is distributed and licensed to you under the terms of <a href="<?php print bccl_get_license_deed_url(); ?>">this license</a>.  For other licenses, contact <?php the_author(); ?>.</p><?php } ?>


			</div>
		</div>
		
	<?php comments_template(); ?>

	<?php if (function_exists("bstat_pulse")) { ?>
	<?php
			ob_start();
			bstat_pulse($post_id=$id,$maxwidth=350,$disptext=1,$dispcredit=0);
			$buffer = ob_get_contents();
			ob_end_clean();
			if ($buffer) {
				print '<h2>Story pulse</h2>';
				print $buffer;
			}
	 ?>
	<?php } ?>

	<?php endwhile; else: ?>
	
		<p>Sorry, no posts matched your criteria.</p>
	
<?php endif; ?>
	
	</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>
