/**** AD STYLES *****/

.ad-after-content, .ad-after-title {
	text-align: center;
	margin-top: 1em;
}

.ad-intermix {
        text-align: center;
	margin-bottom: 1em;
}

.ad-tip-block {
}

.ad-sidebar {
	margin-top: 1em;
}

.ad-header {
	position: absolute;
	top: 0px;
	left: 0px;
	margin-top: 20px;
	margin-left: 20px;
}

/******* END AD STYLES ********/